<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:str="http://mathdoc.fr/string-function-namespace"
  xmlns:oai="http://www.openarchives.org/OAI/2.0/"
  xpath-default-namespace="http://yadda.icm.edu.pl/bwmeta-2.2.0.xsd"
  xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns="http://jats.nlm.nih.gov"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  exclude-result-prefixes="oai xlink str xsi">
  
  <xsl:import href="eudml-utils.xsl"/>
    
  <xsl:param name="placeholderText" />

  <xsl:template match="//bwmeta/element">
    
    <xsl:variable name="lang" select="language[1]/@lang" />
    <article xsi:schemaLocation="http://jats.nlm.nih.gov http://eudml.org/schema/2.0/eudml-article-2.0.xsd">
      <xsl:if test="$lang != ''">
        <xsl:attribute name="xml:lang" select="str:lang($lang)" />
      </xsl:if>
      <front>
        <xsl:if test="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']">
          <journal-meta>
            <xsl:apply-templates select="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Journal']" />
            <xsl:apply-templates select="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Publisher']/contributor[@role = 'publisher']" />
          </journal-meta>
        </xsl:if>
        <article-meta>
          <article-id pub-id-type="yadda-id">
            <xsl:value-of select="@id" />
          </article-id>
          <title-group>
            <xsl:choose>
              <xsl:when test="name[@lang = $lang]">
                <xsl:apply-templates select="name[@lang = $lang]" />
                <xsl:apply-templates select="name[@lang != $lang]" mode="trans" />
              </xsl:when>
              <xsl:otherwise>
                <xsl:apply-templates select="name[1]" />
                <xsl:apply-templates select="name[not(1)]" mode="trans" />
              </xsl:otherwise>
            </xsl:choose>
          </title-group>
          <xsl:if test="contributor[@role = 'author']">
            <contrib-group content-type="authors">
              <xsl:apply-templates select="contributor[@role = 'author']" />
            </contrib-group>
          </xsl:if>
          
          <xsl:choose>
            <xsl:when test="date[@type = 'published'][@year]">
              <xsl:apply-templates select="date[@type = 'published']" />
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates select="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Year']" />
            </xsl:otherwise>
          </xsl:choose>
          
          <xsl:apply-templates select="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Volume']" />
          <xsl:apply-templates select="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Number']" />
          <xsl:apply-templates select="structure[@hierarchy = 'bwmeta1.hierarchy-class.hierarchy_Journal']/current[@level = 'bwmeta1.level.hierarchy_Journal_Article']" />
          
          <xsl:apply-templates select="contents/file[@format = 'application/pdf']" />
          
          <ext-link><xsl:value-of select="$placeholderText" /></ext-link>
          
          <xsl:apply-templates select="@id" mode="selfuri" />
          <xsl:apply-templates select="contents/file[@format = 'application/pdf']" mode="selfuri" />
          
          <xsl:apply-templates select="description[@lang = $lang]" />
          <xsl:apply-templates select="description[@lang != $lang]" mode="trans" />
          
          <xsl:apply-templates select="tags" />

          <custom-meta-group>
            <custom-meta>
              <meta-name>provider</meta-name>
              <meta-value>yadda.icm.edu.pl</meta-value>
            </custom-meta>
          </custom-meta-group>
        </article-meta>
      </front>
      <xsl:if test="relation/@type = 'reference-to'">
        <back>
          <ref-list>
            <xsl:apply-templates select="relation[@type = 'reference-to']" />
          </ref-list>
        </back>
      </xsl:if>
    </article>
  </xsl:template>
  
  <xsl:template match="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Journal']">
    <journal-id journal-id-type="yadda-id">
      <xsl:value-of select="@identity" />
    </journal-id>
    <journal-title-group>
      <xsl:apply-templates select="name" />
      <!-- <xsl:apply-templates select="name[@lang = ancestor::element/language]" />
      <xsl:apply-templates select="name[@lang != ancestor::element/language]" mode="trans" /> -->
    </journal-title-group>
    <xsl:apply-templates select="id[@scheme = 'bwmeta1.id-class.ISSN']" />
  </xsl:template>
  
  <xsl:template match="ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Journal']/name">
    <journal-title>
      <xsl:value-of select="." />
    </journal-title>
  </xsl:template>
  
  <xsl:template match="ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Journal']/name" mode="trans">
    <trans-title-group xml:lang="{str:lang(@lang)}">
      <trans-title>
        <xsl:value-of select="." />
      </trans-title>
    </trans-title-group>
  </xsl:template>
  
  <xsl:template match="id[@scheme = 'bwmeta1.id-class.ISSN']">
    <issn>
      <xsl:value-of select="@value" />
    </issn>
  </xsl:template>
  
  <xsl:template match="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Publisher']/contributor[@role = 'publisher']">
    <publisher>
      <xsl:apply-templates select="attribute[@key = 'institution.name']" />
      <xsl:apply-templates select="attribute[@key = 'institution.address']" />
    </publisher>
  </xsl:template>
  
  <xsl:template match="contributor[@role = 'publisher']/attribute[@key = 'institution.name']">
    <publisher-name>
      <xsl:value-of select="value" />
    </publisher-name>
  </xsl:template>
  
  <xsl:template match="contributor[@role = 'publisher']/attribute[@key = 'institution.address']">
    <publisher-loc>
      <xsl:value-of select="value" />
    </publisher-loc>
  </xsl:template>
  
  <xsl:template match="name">
    <article-title>
      <xsl:value-of select="." />
    </article-title>
  </xsl:template>
  
  <xsl:template match="name" mode="trans">
    <trans-title-group xml:lang="{str:lang(@lang)}">
      <trans-title>
        <xsl:value-of select="." />
      </trans-title>
    </trans-title-group>
  </xsl:template>

  <xsl:template match="contributor[@role = 'author']">
    <contrib contrib-type="author">
      <xsl:choose>
        <xsl:when test="attribute[@key = 'person.firstname'] and attribute[@key = 'person.surname']">
          <name>
            <surname>
              <xsl:value-of select="attribute[@key = 'person.surname']/value" />
            </surname>
            <given-names>
              <xsl:value-of select="attribute[@key = 'person.firstname']/value" />
            </given-names>
          </name>
        </xsl:when>
        <xsl:otherwise>
          <string-name>
            <xsl:value-of select="name[@type = 'canonical']" />
          </string-name>
        </xsl:otherwise>
      </xsl:choose>
    </contrib>
  </xsl:template>
  
  <xsl:template match="date[@type = 'published'] | structure/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Year']">
    <pub-date>
      <year>
        <xsl:if test="self::date and @year">
          <xsl:value-of select="@year" />
        </xsl:if>
        <xsl:if test="self::date and not(@year)">
          <xsl:value-of select="." />
        </xsl:if>
        <xsl:if test="self::ancestor">
          <xsl:value-of select="name" />
        </xsl:if>
      </year>
    </pub-date>
  </xsl:template>
  
  <xsl:template match="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Volume']">
    <volume>
      <xsl:value-of select="name" />
    </volume>
  </xsl:template>
  
  <xsl:template match="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Journal_Number']">
    <issue>
      <xsl:value-of select="name" />
    </issue>
  </xsl:template>
  
  <xsl:template match="structure/current[@level = 'bwmeta1.level.hierarchy_Journal_Article']">
    <xsl:choose>
      <xsl:when test="matches(@position, '^\[?[\p{N}IVX]+\]?$')">
        <fpage>
          <xsl:value-of select="@position" />
        </fpage>
      </xsl:when>
      <xsl:when test="matches(@position, '^\[?[\p{N}IVX]+\]?-\[?[\p{N}IVX]+\]?$')">
        <fpage>
          <xsl:value-of select="substring-before(@position, '-')" />
        </fpage>
        <lpage>
          <xsl:value-of select="substring-after(@position, '-')" />
        </lpage>
      </xsl:when>
      <xsl:otherwise>
        <page-range>
          <xsl:value-of select="@position" />
        </page-range>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="contents/file[@format = 'application/pdf']">
    <ext-link ext-link-type="eudml-fulltext:application/pdf" specific-use="index,enhance,serve" xlink:href="{location}">
      <xsl:text>MetaFull (PDF)</xsl:text>
    </ext-link>
  </xsl:template>
  
  <xsl:template match="contents/file[@format = 'application/pdf']" mode="selfuri">
    <self-uri content-type="application/pdf" xlink:href="{location}">
      <xsl:text>Full (PDF)</xsl:text>
    </self-uri>
  </xsl:template>
  
  <xsl:template match="element/@id" mode="selfuri">
    <self-uri xlink:href="http://pldml.icm.edu.pl/pldml/element/{.}">
      <xsl:text>Access to full text</xsl:text>
    </self-uri>
  </xsl:template>
  
  <xsl:template match="description">
    <abstract>
      <p>
        <xsl:value-of select="." />
      </p>
    </abstract>
  </xsl:template>
  
  <xsl:template match="description" mode="trans">
    <trans-abstract xml:lang="{str:lang(@lang)}">
      <p>
        <xsl:value-of select="." />
      </p>
    </trans-abstract>
  </xsl:template>
  
  <xsl:template match="tags">
    <kwd-group>
      <xsl:if test="@lang != ancestor::element/language/@lang">
        <xsl:attribute name="xml:lang" select="str:lang(@lang)" />
      </xsl:if>
      <!-- <xsl:if test="@type != 'keyword'">
        <xsl:attribute name="kwd-group-type" select="@type" />
      </xsl:if> -->
      <xsl:apply-templates select="tag" />
    </kwd-group>
  </xsl:template>
  
  <xsl:template match="tag">
    <kwd>
      <xsl:value-of select="." />
    </kwd>
  </xsl:template>
  
  <xsl:template match="relation[@type = 'reference-to']">
    <ref>
      <xsl:apply-templates select="attribute" />
    </ref>
  </xsl:template>
  
  <xsl:template match="relation[@type = 'reference-to']/attribute[@key = 'reference-parsed-key']">
    <label>
      <xsl:value-of select="value" />
    </label>
  </xsl:template>
  
  <xsl:template match="relation[@type = 'reference-to']/attribute[@key = 'reference-text']">
    <mixed-citation>
      <xsl:value-of select="value" />
    </mixed-citation>
  </xsl:template>
</xsl:stylesheet>